@@ -6,6 +6,3 @@ from . import base64_jinja
 class FptMacros(AirflowPlugin):
     name = "flowpytertask"
     macros = [base64_jinja.b64_encode, base64_jinja.dump_yaml]
-
-def hello_plugin():
-    print("PLUGIN")
\ No newline at end of file
